@@ -13,9 +13,9 @@ System dependencies: iproute2, ethtool
 
 import argparse
 import json
+import re
 import subprocess
 import sys
-import re
 
 
 def main():
@@ -141,7 +141,7 @@ def node_attrs(link):
     return " ".join(f"{k}={v}" for k, v in attrs.items())
 
 
-def ip(*cmd):
+def ip(*cmd):  # pylint: disable=invalid-name
     args = ["ip", "-d", "-j"] + list(cmd)
     out = subprocess.check_output(args).decode("utf-8")
     if not out.strip():
